------ Differences with Spagic 2.3.0 ------
CREATE SEQUENCE seq_search_query;

Create table search_query (
   id_query Integer NOT NULL ,
   label Varchar(100) NOT NULL UNIQUE,
   query Text NOT NULL,
Primary Key (id_query));

-- Create view section
CREATE VIEW bc_input_messages AS
  SELECT s.id_step AS id_binding_component, COUNT(logJournal.id_log) AS input_messages 
	FROM step s, process p, transition_instance t, log_journal logJournal,property_step propertyStep, property pty  	
	WHERE s.id_process = p.id_process AND s.id_process = (SELECT max(pSub.id_process) AS idProcess FROM process pSub WHERE pSub.name=p.name)				
				AND s.id_step = t.id_step_source
				AND t.id_journal = logJournal.id_journal 				
				AND s.id_step=propertyStep.id_step 				
				AND propertyStep.id_property=pty.id_property
				AND pty.code='im.servicebindingname'
				AND ((s.is_start AND logJournal.id_state IN (0, 3)) 
						OR (pty.value IN ('JBI-WebServicePipeline','JBI-TCPIP-Pipeline','JBI-CXF-Pipeline') AND logJournal.id_state=3 )
						) 				
	group by s.id_step;

CREATE VIEW bc_output_messages AS
  SELECT s.id_step AS id_binding_component, COUNT(logJournal.id_log) AS output_messages 
	FROM step s, process p, transition_instance t, log_journal logJournal,property_step propertyStep, property pty  	
	WHERE s.id_process = p.id_process AND s.id_process = (SELECT max(pSub.id_process) AS idProcess FROM process pSub WHERE pSub.name=p.name)								
				AND t.id_journal = logJournal.id_journal 				
				AND s.id_step=propertyStep.id_step 				
				AND propertyStep.id_property=pty.id_property
				AND pty.code='im.servicebindingname'
				AND ((s.is_end AND logJournal.id_state=1 AND s.id_step = t.id_step_target)
						OR (pty.value IN ('JBI-WebServicePipeline','JBI-TCPIP-Pipeline','JBI-CXF-Pipeline') AND s.id_step = t.id_step_source AND logJournal.id_state=4 )
            OR (s.is_start AND logJournal.id_state = 4 AND s.id_step = t.id_step_source)						
						) 				
	group by s.id_step;
	
CREATE VIEW bc_error_messages AS
  SELECT s.id_step AS id_binding_component, COUNT(logJournal.id_log) AS error_messages 
	FROM step s, process p, transition_instance t, log_journal logJournal,property_step propertyStep, property pty  	
	WHERE s.id_process = p.id_process AND s.id_process = (SELECT max(pSub.id_process) AS idProcess FROM process pSub WHERE pSub.name=p.name)								
				AND t.id_journal = logJournal.id_journal 				
				AND s.id_step=propertyStep.id_step 				
				AND propertyStep.id_property=pty.id_property
				AND pty.code='im.servicebindingname'
				AND ((s.is_start AND s.id_step = t.id_step_source AND logJournal.id_state IN (2, 5))
						OR(s.is_end  AND s.id_step = t.id_step_target AND logJournal.id_state IN (2, 5))
						OR (pty.value IN ('JBI-WebServicePipeline','JBI-TCPIP-Pipeline','JBI-CXF-Pipeline') AND logJournal.id_state=5
								AND (s.id_step = t.id_step_target OR s.id_step = t.id_step_source))
						) 				
	group by s.id_step;

-- Differences with Spagic 2.3.0 --

ALTER TABLE process_instance DROP INDEX idx_correlation_id,
 ADD INDEX idx_process_instance_01 (id_correlation);
/* Cannot be unique due to restarted instances */
Create Index idx_transition_instance_01 ON transition_instance using btree (id_message);
Create Index idx_wait_data_01 ON wait_data using btree (id_correlation);
Create Index idx_log_journal_01 ON log_journal using btree (id_journal);
Create Index idx_log_journal_02 ON log_journal using btree (id_state);


-- Differences with Spagic 2.4.0 --

ALTER TABLE process_instance ADD COLUMN id_parent_process_instance Bigint DEFAULT NULL AFTER id_process_instance;
ALTER TABLE process_instance add foreign key (id_parent_process_instance) references process_instance (id_process_instance) on update restrict on delete restrict;

Create table sub_process 
(
	id_process Bigint NOT NULL,
	id_subprocess Bigint NOT NULL,
	descr Varchar(50),
 primary key (id_process,id_subprocess)
) Without Oids;

ALTER TABLE sub_process add foreign key (id_process) references process (id_process) on delete  restrict on update  restrict;
ALTER TABLE sub_process add foreign key (id_subprocess) references process (id_process) on delete  restrict on update  restrict;

INSERT INTO type_service (id_ts, value) VALUES(6, 'JBPM-PROCESS');

INSERT INTO transition_state (id_state,state_value) VALUES(21, 'JBPM_START_ACTIVITY');
INSERT INTO transition_state (id_state,state_value) VALUES(22, 'JBPM_END_ACTIVITY');
INSERT INTO transition_state (id_state,state_value) VALUES(23, 'JBPM_FAULTED_ACTIVITY');


ALTER TABLE process_instance ADD COLUMN id_process_execution_state Bigint NOT NULL Default 0 AFTER id_pool;
ALTER TABLE process ADD COLUMN id_monitoring_type Bigint NOT NULL Default 0 AFTER monitor_enabled;


Create table process_execution_state
(
	id_process_execution_state Double precision NOT NULL,
	state_value Varchar(100),
 primary key (id_process_execution_state)
) Without Oids;

Create table monitoring_type
(
	id_monitoring_type Double precision NOT NULL,
	type_value Varchar(100),
 primary key (id_monitoring_type)
) Without Oids;

INSERT INTO pool_type (id_pool_type,id_rule_det_pool_type,name,description,pool_type_version) VALUES(nextval('seq_pool_type'),NULL,'ANONYMOUS','POOL TYPE FOR DYNAMIC LINKS','0');

INSERT INTO process_execution_state (id_process_execution_state,state_value) VALUES(0, 'NORMAL_EXECUTION');
INSERT INTO process_execution_state (id_process_execution_state,state_value) VALUES(1, 'PAUSE_EXECUTION');
INSERT INTO process_execution_state (id_process_execution_state,state_value) VALUES(2, 'STOP_EXECUTION');

INSERT INTO monitoring_type (id_monitoring_type,type_value) VALUES(0, 'ASYNCHRONOUS');
INSERT INTO monitoring_type (id_monitoring_type,type_value) VALUES(1, 'SYNCHRONOUS');


ALTER TABLE process_instance add  foreign key (id_process_execution_state) references process_execution_state (id_process_execution_state) on update restrict on delete restrict;

ALTER TABLE process add  foreign key (id_monitoring_type) references monitoring_type (id_monitoring_type) on update restrict on delete restrict;


-- Transition_data as CLOB in Transition Instance
-- Old data in the columns transition_data and transition_data_out
-- will be lost
BEGIN;
ALTER TABLE transition_instance DROP COLUMN transition_data;
ALTER TABLE transition_instance ADD COLUMN transition_data Text;
COMMIT; 
BEGIN;
ALTER TABLE transition_instance DROP COLUMN transition_data_out;
ALTER TABLE transition_instance ADD COLUMN transition_data_out Text;
COMMIT; 

BEGIN;
ALTER TABLE transition_instance DROP COLUMN ID_EXT_PROCESS_INSTANCE;
ALTER TABLE transition_instance ADD COLUMN ID_EXT_PROCESS_INSTANCE Bigint;
COMMIT;


-- 2.5.0 performance improvement in backup
Create table temporary_process_instance
(
	id_process_instance Bigint NOT NULL,
 primary key (id_process_instance)
) Without Oids;

ALTER TABLE transition_instance ADD COLUMN runtime_warning Boolean DEFAULT FALSE AFTER attachment_out;